@@ -1,6 +1,7 @@
 from agentmake import AGENTMAKE_USER_DIR, readTextFile, writeTextFile
-import os, shutil, pprint
 from pathlib import Path
+from biblemate.ui.selection_dialog import TerminalModeDialogs
+import os, shutil, pprint
 
 CONFIG_FILE = os.path.join(os.path.dirname(os.path.realpath(__file__)), "config.py")
 CONFIG_FILE_BACKUP = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "config.py")
@@ -16,6 +17,7 @@ default_config = '''banner_title=""
 *lite=False
 *web_browser=False
 *hide_tools_order=True
+*skip_connection_check=False
 *default_bible="NET"
 *default_commentary="CBSC"
 *default_encyclopedia="ISB"
@@ -23,6 +25,7 @@ default_config = '''banner_title=""
 *max_semantic_matches=15
 *max_log_lines=2000
 *mcp_port=33333
+*mcp_timeout=9999999999
 *embedding_model="paraphrase-multilingual"
 *disabled_tools=['search_1_chronicles_only',
 'search_1_corinthians_only',
@@ -112,6 +115,7 @@ max_steps={config.max_steps}
 lite={config.lite}
 web_browser={config.web_browser}
 hide_tools_order={config.hide_tools_order}
+skip_connection_check={config.skip_connection_check}
 default_bible="{config.default_bible}"
 default_commentary="{config.default_commentary}"
 default_encyclopedia="{config.default_encyclopedia}"
@@ -119,6 +123,7 @@ default_lexicon="{config.default_lexicon}"
 max_semantic_matches={config.max_semantic_matches}
 max_log_lines={config.max_log_lines}
 mcp_port={config.mcp_port}
+mcp_timeout={config.mcp_timeout}
 embedding_model="{config.embedding_model}"
 disabled_tools={pprint.pformat(config.disabled_tools)}"""
     writeTextFile(CONFIG_FILE_BACKUP if backup else CONFIG_FILE, configurations)
@@ -135,11 +140,75 @@ if just_upgraded:
 
 # temporary config
 config.current_prompt = ""
+config.last_multi_bible_selection = [config.default_bible]
+config.last_bible_reference = ""
 config.last_book = 43
 config.last_chapter = 3
 config.last_verse = 16
-
-BIBLEMATE_VERSION = readTextFile(os.path.join(os.path.dirname(os.path.realpath(__file__)), "version.txt"))
+config.backup_required = False
+config.export_item = ""
+config.action_list = {
+    # general
+    ".ideas": "generate ideas for prompts to try",
+    ".exit": "exit current prompt",
+    # conversations
+    ".new": "new conversation",
+    ".trim": "trim conversation",
+    ".edit": "edit conversation",
+    ".reload": "reload conversation",
+    ".import": "import conversation",
+    ".export": "export conversation",
+    ".backup": "backup conversation",
+    ".find": "search conversation",
+    # UBA content
+    ".bible": "open bible verse",
+    ".chapter": "open bible chapter",
+    ".compare": "compare bible verse in different versions",
+    ".comparechapter": "compare bible chapter in different versions",
+    ".xref": "open cross-references",
+    ".treasury": "open treasury of scripture knowledge",
+    ".commentary": "open commentary",
+    ".aicommentary": "open AI commentary",
+    ".index": "open verse study indexes",
+    ".translation": "open interlinear, literal & dynamic translations",
+    ".discourse": "open discourse analysis",
+    ".morphology": "open morphology data",
+    ".search": "search bible",
+    ".dictionary": "search dictionary",
+    ".encyclopedia": "search encyclopedia",
+    ".lexicon": "search lexicon",
+    ".parallel": "search parallel passages",
+    ".promise": "search bible promises",
+    ".topic": "search bible topic",
+    ".name": "search bible name",
+    ".character": "search bible character",
+    ".location": "search bible location",
+    ".chronology": "open bible chronology",
+    ".defaultbible": "configure default bible",
+    ".defaultcommentary": "configure default commentary",
+    ".defaultencyclopedia": "configure default encyclopedia",
+    ".defaultlexicon": "configure default lexicon",
+    # resource information
+    ".tools": "list available tools",
+    ".plans": "list available plans",
+    ".resources": "list UniqueBible resources",
+    # configurations
+    ".backend": "configure backend",
+    ".steps": "configure the maximum number of steps allowed",
+    ".matches": "configure the maximum number of semantic matches",
+    ".mode": "configure AI mode",
+    #".agent": "switch to agent mode",
+    #".partner": "switch to partner mode",
+    #".chat": "switch to chat mode",
+    ".autosuggestions": "toggle auto input suggestions",
+    ".promptengineer": "toggle auto prompt engineering",
+    ".lite": "toggle lite context",
+    # file access
+    ".open": "open file or folder",
+    ".download": "download data files",
+    # help
+    ".help": "help page",
+}
 
 # copy etextedit plugins
 ETEXTEDIT_USER_PULGIN_DIR = os.path.join(os.path.expanduser("~"), "etextedit", "plugins")
@@ -151,14 +220,18 @@ for file_name in os.listdir(BIBLEMATE_ETEXTEDIT_PLUGINS):
     if file_name.endswith(".py") and os.path.isfile(full_file_name) and not os.path.isfile(os.path.join(ETEXTEDIT_USER_PULGIN_DIR, file_name)):
         shutil.copy(full_file_name, ETEXTEDIT_USER_PULGIN_DIR)
 
+# constants
 AGENTMAKE_CONFIG = {
     "print_on_terminal": False,
     "word_wrap": False,
 }
 OLLAMA_NOT_FOUND = "`Ollama` is not found! BibleMate AI uses `Ollama` to generate embeddings for semantic searches. You may install it from https://ollama.com/ so that you can perform semantic searches of the Bible with BibleMate AI."
+BIBLEMATE_VERSION = readTextFile(os.path.join(os.path.dirname(os.path.realpath(__file__)), "version.txt"))
+BIBLEMATE_USER_DIR = os.path.join(AGENTMAKE_USER_DIR, "biblemate")
 BIBLEMATEDATA = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "data")
 if not os.path.isdir(BIBLEMATEDATA):
     Path(BIBLEMATEDATA).mkdir(parents=True, exist_ok=True)
+DIALOGS = TerminalModeDialogs()
 
 def fix_string(content):
     return content.replace(" ", " ").replace("‑", "-")
\ No newline at end of file
